summaryrefslogtreecommitdiffstats
path: root/kalzium/src/somwidget_impl.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commiteb570158698cf61dad4f77d950ef908160f6c3cc (patch)
tree649bf182bcf0a20bed5035d25ffd77de5aee138a /kalzium/src/somwidget_impl.h
parentd8762de95349dc6edaa34db9bf699b367c1af6b1 (diff)
downloadtdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.tar.gz
tdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalzium/src/somwidget_impl.h')
-rw-r--r--kalzium/src/somwidget_impl.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kalzium/src/somwidget_impl.h b/kalzium/src/somwidget_impl.h
index 5d32dbdc..fcf83a12 100644
--- a/kalzium/src/somwidget_impl.h
+++ b/kalzium/src/somwidget_impl.h
@@ -33,10 +33,10 @@ class SOMWidgetIMPL : public SOMWidget
public:
/**
* @param tqparent The tqparent of this widget
* @param name The name of this widget
*/
- SOMWidgetIMPL( TQWidget *tqparent = 0, const char* name = 0 );
+ SOMWidgetIMPL( TQWidget *parent = 0, const char* name = 0 );
public slots:
/**
@@ -33,10 +33,10 @@ class SOMWidgetIMPL : public SOMWidget
public:
/**
- * @param tqparent The tqparent of this widget
+ * @param parent The parent of this widget
* @param name The name of this widget
*/